pub struct DecryptKey(/* private fields */);Expand description
An initialized key which can be used for decrypting
Implementations
Sourceimpl DecryptKey
impl DecryptKey
Sourcepub fn new_128(key: &[u8; 16]) -> DecryptKey
pub fn new_128(key: &[u8; 16]) -> DecryptKey
Initializes a decryption key from an appropriately sized array of bytes for AES-128 operations.
Sourcepub fn new_256(key: &[u8; 32]) -> DecryptKey
pub fn new_256(key: &[u8; 32]) -> DecryptKey
Initializes a decryption key from an appropriately sized array of bytes for AES-256 operations.
Sourcepub fn decrypt_in_place(&self, block: &mut Block)
pub fn decrypt_in_place(&self, block: &mut Block)
Replace block with its decrypted version.