pub struct EncryptKey(/* private fields */);Expand description
An initialized key which can be used for encrypting.
Implementations
Sourceimpl EncryptKey
impl EncryptKey
Sourcepub fn new_128(key: &[u8; 16]) -> Self
pub fn new_128(key: &[u8; 16]) -> Self
Initializes an encryption key from an appropriately sized array of bytes
Sourcepub fn new_256(key: &[u8; 32]) -> Self
pub fn new_256(key: &[u8; 32]) -> Self
Initializes an encryption key from an appropriately sized array of bytes
Sourcepub fn encrypt_in_place(&self, block: &mut Block)
pub fn encrypt_in_place(&self, block: &mut Block)
Replace block with its encrypted version.