pub struct InsecureSha1 { /* private fields */ }Expand description
The insecure SHA-1 hash algorithm.
Some existing protocols depend on SHA-1 and so it is provided here, but it does not provide collision resistance and should not be used if at all avoidable. Use SHA-256 instead.
Implementations
Sourceimpl InsecureSha1
impl InsecureSha1