Hkdf

Struct Hkdf 

pub struct Hkdf<MD: Algorithm>(/* private fields */);
HKDF for any of the implemented hash functions. The aliases HkdfSha256 and HkdfSha512 are provided for the most common cases.

Implementations

Source

impl<MD: Algorithm> Hkdf<MD>

pub const MAX_OUTPUT_LEN: usize

The maximum number of bytes of key material that can be produced.

pub fn derive<const N: usize>( secret: &[u8], salt: Salt<'_>, info: &[u8], ) -> [u8; N]

Derive key material from the given secret, salt, and info. Attempting to derive more than 255 bytes is a compile-time error, see derive_into for longer outputs.

The semantics of the arguments are complex. See https://datatracker.ietf.org/doc/html/rfc5869#section-3.

pub fn derive_into( secret: &[u8], salt: Salt<'_>, info: &[u8], out: &mut [u8], ) -> Result<(), TooLong>

Derive key material from the given secret, salt, and info. Attempting to derive more than MAX_OUTPUT_LEN bytes is a run-time error.

The semantics of the arguments are complex. See https://datatracker.ietf.org/doc/html/rfc5869#section-3.

pub fn extract(secret: &[u8], salt: Salt<'_>) -> Prk

Extract a pseudo-random key from the given secret and salt. This can be used to avoid redoing computation when computing several keys that vary only in the info parameter.