HmacSha256

Struct HmacSha256 

pub struct HmacSha256(/* private fields */);
HMAC-SHA256.

Implementations

Source

impl HmacSha256

pub fn mac(key: &[u8], data: &[u8]) -> [u8; 32]

Computes the HMAC-SHA256 of data as a one-shot operation.

pub fn new(key: &[u8; 32]) -> Self

Creates a new HMAC-SHA256 operation from a fixed-length key.

pub fn new_from_slice(key: &[u8]) -> Self

Creates a new HMAC-SHA256 operation from a variable-length key.

pub fn update(&mut self, data: &[u8])

Hashes the provided input into the HMAC operation.

pub fn digest(self) -> [u8; 32]

Computes the final HMAC value, consuming the object.

pub fn verify_slice(self, tag: &[u8]) -> Result<(), InvalidSignatureError>

Checks that the provided tag value matches the computed HMAC value.

pub fn verify(self, tag: &[u8; 32]) -> Result<(), InvalidSignatureError>

Checks that the provided tag value matches the computed HMAC value.

pub fn verify_truncated_left( self, tag: &[u8], ) -> Result<(), InvalidSignatureError>

Checks that the provided tag value matches the computed HMAC, truncated to the input tag’s length.

Truncating an HMAC reduces the security of the construction. Callers must ensure tag’s length matches the desired HMAC length and security level.