RecipientContext

Struct RecipientContext 

pub struct RecipientContext(/* private fields */);
HPKE recipient context. Callers may use open() to decrypt messages from the sender.

Implementations

Source

impl RecipientContext

pub fn new( params: &Params, recipient_priv_key: &[u8], encapsulated_key: &[u8], info: &[u8], ) -> Option<Self>

New implements the SetupBaseR HPKE operation, which decapsulates the shared secret in encapsulated_key with recipient_priv_key and sets up a recipient context. These are stored and returned in the newly created RecipientContext.

Note that encapsulated_key may be invalid, in which case this function will return an error.

On success, callers may use open() to decrypt messages from the sender.

pub fn open(&mut self, ciphertext: &[u8], aad: &[u8]) -> Option<Vec<u8>>

Open authenticates aad and decrypts ciphertext. It returns an error on failure.

Note that HPKE encryption is stateful and ordered. The sender’s first call to seal() must correspond to the recipient’s first call to open(), etc.

pub fn export(&mut self, context: &[u8], out_len: usize) -> Vec<u8>

Exports a secret of length out_len from the HPKE context using context as the context string.