PublicKey65

Struct PublicKey65 

pub struct PublicKey65(/* private fields */);
An ML-DSA-65 public key.

Implementations

Source

impl PublicKey65

pub fn parse(encoded: &[u8]) -> Option<Self>

Parses a public key from a byte slice.

pub fn to_bytes(&self) -> Vec<u8>

Return the serialization of this public key.

pub fn verify( &self, msg: &[u8], signature: &[u8], ) -> Result<(), InvalidSignatureError>

Verifies a signature for a given message using this public key.

pub fn verify_with_context( &self, msg: &[u8], signature: &[u8], context: &[u8], ) -> Result<(), InvalidSignatureError>

Verifies a signature for a given message using this public key and the given context.

pub fn verify_prehashed( &self, prehash: Prehash65, signature: &[u8], ) -> Result<(), InvalidSignatureError>

Verify pre-hashed data.

pub fn prehash(&self) -> Prehash65

Start a pre-hashing operation using this public key.