pub struct PublicKey87(/* private fields */);Expand description
An ML-DSA-87 public key.
Implementations
Sourceimpl PublicKey87
impl PublicKey87
Sourcepub fn verify(
&self,
msg: &[u8],
signature: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify( &self, msg: &[u8], signature: &[u8], ) -> Result<(), InvalidSignatureError>
Verifies a signature for a given message using this public key.
Sourcepub fn verify_with_context(
&self,
msg: &[u8],
signature: &[u8],
context: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify_with_context( &self, msg: &[u8], signature: &[u8], context: &[u8], ) -> Result<(), InvalidSignatureError>
Verifies a signature for a given message using this public key and the given context.
Sourcepub fn verify_prehashed(
&self,
prehash: Prehash87,
signature: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify_prehashed( &self, prehash: Prehash87, signature: &[u8], ) -> Result<(), InvalidSignatureError>
Verify pre-hashed data.