PublicKey768

Struct PublicKey768 

pub struct PublicKey768(/* private fields */);
An ML-KEM-768 public key.

Implementations

Source

impl PublicKey768

pub fn parse(encoded: &[u8]) -> Option<Self>

Parse a public key from NIST’s defined format.

pub fn to_bytes(&self) -> Vec<u8>

Return the serialization of this public key.

pub fn encapsulate(&self) -> (Vec<u8>, [u8; 32])

Generate a secret key and encrypt it to this public key, returning the ciphertext and the shared secret key.