PrivateKey

Struct PrivateKey 

pub struct PrivateKey(/* private fields */);
An RSA private key.

Implementations

Source

impl PrivateKey

pub fn generate(size: KeySize) -> Self

Generate a fresh RSA private key of the given size.

pub fn from_der_rsa_private_key(der: &[u8]) -> Option<Self>

Parse a DER-encoded RSAPrivateKey structure (from RFC 8017).

pub fn to_der_rsa_private_key(&self) -> Buffer

Serialize to a DER-encoded RSAPrivateKey structure (from RFC 8017).

pub fn from_der_private_key_info(der: &[u8]) -> Option<Self>

Parse a DER-encrypted PrivateKeyInfo struct (from RFC 5208). This is often called “PKCS#8 format”.

pub fn to_der_private_key_info(&self) -> Buffer

Serialize to a DER-encrypted PrivateKeyInfo struct (from RFC 5208). This is often called “PKCS#8 format”.

pub fn sign_pkcs1<Hash: Algorithm>(&self, to_be_signed: &[u8]) -> Vec<u8>

Compute the signature of the digest of to_be_signed with PKCS#1 using this private key. The specified hash function is used to compute the

pub fn sign_pss<Hash: Algorithm>(&self, to_be_signed: &[u8]) -> Vec<u8>

Compute the signature of the digest of to_be_signed with RSASSA-PSS using this private key. The specified hash function is used to compute the digest and for MGF1. The salt length is set to be equal to the digest length.

pub fn as_public(&self) -> PublicKey

Return the public key corresponding to this private key.