PublicKey

Struct PublicKey 

pub struct PublicKey(/* private fields */);
An RSA public key.

Implementations

Source

impl PublicKey

pub fn from_der_rsa_public_key(der: &[u8]) -> Option<Self>

Parse a DER-encoded RSAPublicKey structure (from RFC 8017).

pub fn to_der_rsa_public_key(&self) -> Buffer

Serialize to a DER-encoded RSAPublicKey structure (from RFC 8017).

pub fn from_der_subject_public_key_info(spki: &[u8]) -> Option<Self>

Parse a DER-encoded SubjectPublicKeyInfo. This format is found in, for example, X.509 certificates.

pub fn to_der_subject_public_key_info(&self) -> Buffer

Serialize to a DER-encoded SubjectPublicKeyInfo. This format is found in, for example, X.509 certificates.

pub fn verify_pkcs1<Hash: Algorithm>( &self, signed_msg: &[u8], signature: &[u8], ) -> Result<(), InvalidSignatureError>

Verify that signature is a valid signature of a digest of signed_msg, by this public key. The digest of the message will be computed with the specified hash function.

pub fn verify_pss<Hash: Algorithm>( &self, signed_msg: &[u8], signature: &[u8], ) -> Result<(), InvalidSignatureError>

Verify that signature is a valid RSA-PSS signature of a digest of signed_msg, by this public key. The specified hash function is used to compute the digest and for MGF1. The salt length is set to be equal to the digest length.