PrivateKey

Struct PrivateKey 

pub struct PrivateKey(/* private fields */);
An SLH-DSA-SHA2-128s private key.

Implementations

Source

impl PrivateKey

pub fn generate() -> (PublicKey, Self)

Generates a random public/private key pair.

pub fn to_public_key(&self) -> PublicKey

Derives the public key corresponding to this private key.

pub fn sign(&self, msg: &[u8]) -> Vec<u8>

Signs a message using this private key.

pub fn sign_with_context(&self, msg: &[u8], context: &[u8]) -> Option<Vec<u8>>

Signs a message using this private key and the given context.

This function returns None if context is longer than 255 bytes.