PublicKey

Struct PublicKey 

pub struct PublicKey(/* private fields */);
An SLH-DSA-SHA2-128s public key.

Implementations

Source

impl PublicKey

pub fn verify( &self, msg: &[u8], signature: &[u8], ) -> Result<(), InvalidSignatureError>

Verifies a signature for a given message using this public key.

pub fn verify_with_context( &self, msg: &[u8], signature: &[u8], context: &[u8], ) -> Result<(), InvalidSignatureError>

Verifies a signature for a given message using this public key and the given context.