PrivateKey

Struct PrivateKey 

pub struct PrivateKey(pub [u8; 32]);
An X25519 private key (a 32-byte string).

Tuple Fields

0: [u8; 32]

Implementations

Source

impl PrivateKey

pub fn compute_shared_key( &self, other_public_key: &PublicKey, ) -> Option<[u8; 32]>

Derive the shared key between this private key and a peer’s public key. Don’t use the shared key directly, rather use a KDF and also include the two public values as inputs.

Will fail and produce None if the peer’s public key is a point of small order. It is safe to react to this in non-constant time.

pub fn generate() -> (PublicKey, PrivateKey)

Generate a new key pair.

pub fn to_public(&self) -> PublicKey

Compute the public key corresponding to this private key.