BlockCipher

Trait BlockCipher 

pub trait BlockCipher {
    type Key: AsRef<[u8]>;
    type Nonce: AsRef<[u8]>;

    // Required methods
    fn new_encrypt(key: &Self::Key, iv: &Self::Nonce) -> Self;
    fn new_decrypt(key: &Self::Key, iv: &Self::Nonce) -> Self;
    fn encrypt_padded(self, buffer: &[u8]) -> Result<Vec<u8>, CipherError>;
    fn decrypt_padded(self, buffer: &[u8]) -> Result<Vec<u8>, CipherError>;
}
Synchronous block cipher trait.

Required Associated Types

type Key: AsRef<[u8]>

The byte array key type which specifies the size of the key used to instantiate the cipher.

type Nonce: AsRef<[u8]>

The byte array nonce type which specifies the size of the nonce used in the cipher operations.

Required Methods

fn new_encrypt(key: &Self::Key, iv: &Self::Nonce) -> Self

Instantiate a new instance of a block cipher for encryption from a key and iv.

fn new_decrypt(key: &Self::Key, iv: &Self::Nonce) -> Self

Instantiate a new instance of a block cipher for decryption from a key and iv.

fn encrypt_padded(self, buffer: &[u8]) -> Result<Vec<u8>, CipherError>

Encrypts the given data in buffer, and returns the result (with padding) in a newly allocated vector, or a CipherError if the operation was unsuccessful.

fn decrypt_padded(self, buffer: &[u8]) -> Result<Vec<u8>, CipherError>

Decrypts the given data in a buffer, and returns the result (with padding removed) in a newly allocated vector, or a CipherError if the operation was unsuccessful.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors