pub unsafe fn zeroize_mut_byteslice<'a>(
ptr: *mut u8,
capacity: usize,
) -> &'a mut [u8] ⓘExpand description
Sanitize the data pointer and length and reconstitute the mutable slice.
This method will zeroize the content.
This method returns an empty slice if the length is 0.
Safety
Caller must ensure that
ptroutlives'a.- access to
outis exclusive and strictly not aliased. - if
ptris NULL,capacity == 0.