pub struct PublicKey65(/* private fields */);Expand description
An ML-DSA-65 public key.
Implementations
Sourceimpl PublicKey65
impl PublicKey65
Sourcepub fn verify(
&self,
msg: &[u8],
signature: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify( &self, msg: &[u8], signature: &[u8], ) -> Result<(), InvalidSignatureError>
Verifies a signature for a given message using this public key.
Sourcepub fn verify_with_context(
&self,
msg: &[u8],
signature: &[u8],
context: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify_with_context( &self, msg: &[u8], signature: &[u8], context: &[u8], ) -> Result<(), InvalidSignatureError>
Verifies a signature for a given message using this public key and the given context.
Sourcepub fn verify_prehashed(
&self,
prehash: Prehash65,
signature: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify_prehashed( &self, prehash: Prehash65, signature: &[u8], ) -> Result<(), InvalidSignatureError>
Verify pre-hashed data.