pub struct PublicKey(/* private fields */);Expand description
An SLH-DSA-SHA2-128s public key.
Implementations
Sourceimpl PublicKey
impl PublicKey
Sourcepub fn verify(
&self,
msg: &[u8],
signature: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify( &self, msg: &[u8], signature: &[u8], ) -> Result<(), InvalidSignatureError>
Verifies a signature for a given message using this public key.
Sourcepub fn verify_with_context(
&self,
msg: &[u8],
signature: &[u8],
context: &[u8],
) -> Result<(), InvalidSignatureError>
pub fn verify_with_context( &self, msg: &[u8], signature: &[u8], context: &[u8], ) -> Result<(), InvalidSignatureError>
Verifies a signature for a given message using this public key and the given context.