pub struct PrivateKey(pub [u8; 32]);Expand description
An X25519 private key (a 32-byte string).
Tuple Fields
0: [u8; 32]Implementations
Sourceimpl PrivateKey
impl PrivateKey
Derive the shared key between this private key and a peer’s public key. Don’t use the shared key directly, rather use a KDF and also include the two public values as inputs.
Will fail and produce None if the peer’s public key is a point of
small order. It is safe to react to this in non-constant time.
Sourcepub fn generate() -> (PublicKey, PrivateKey)
pub fn generate() -> (PublicKey, PrivateKey)
Generate a new key pair.